@@ -136,6 +136,13 @@ namespace Banshee.Base
                     Catalog.GetString("Columns..."), null,
                     Catalog.GetString("Select which columns to display in the song list"), null),
                 
+                new ActionEntry("ShellAction", null,
+                    Catalog.GetString("Boo Buddy..."), "<control><shift>S",
+                    Catalog.GetString("Open Boo Buddy"), delegate {
+                        BooBuddy.BooBuddyWindow boo_buddy = new BooBuddy.BooBuddyWindow();
+                        boo_buddy.Show();
+                    }),
+                
                 new ActionEntry("ShowEqualizerAction", null,
                     Catalog.GetString("Equalizer"), null,
                     Catalog.GetString("Display the equalizer."), null),
@@ -328,6 +335,7 @@ namespace Banshee.Base
             ui.InsertActionGroup(dap_actions, 0);
             
             this["DebugMenuAction"].Visible = Globals.ArgumentQueue.Contains("debug");
+            this["ShellAction"].Visible = Globals.ArgumentQueue.Contains("debug");
         }
         
         public Action FindActionByName(string actionName)
