@@ -29,7 +29,6 @@
 using System;
 using GLib;
 using Gtk;
-using Sql;
 using System.Collections;
 
 using Mono.Unix;
@@ -76,7 +75,7 @@ namespace Banshee.SmartPlaylist
             if (Filter == null)
                 return null;
             else
-                return Filter.Operator.FormatValues (true, Column, Statement.EscapeQuotes(Value1.ToLower()), null);
+                return Filter.Operator.FormatValues (true, Column, EscapeQuotes(Value1.ToLower()), null);
         }
         
         public override string Value1 {
@@ -471,8 +470,8 @@ namespace Banshee.SmartPlaylist
 
         public override string FilterValues()
         {
-            string pv = Statement.EscapeQuotes(Value1);
-            string pv2 = (spinButton2 == null) ? null : Statement.EscapeQuotes(Value2);
+            string pv = EscapeQuotes(Value1);
+            string pv2 = (spinButton2 == null) ? null : EscapeQuotes(Value2);
 
             if (Filter == null)
                 return null;
