@@ -6,11 +6,10 @@ using System.Collections.Generic;
 using Banshee.Base;
 using Banshee.Sources;
 using Banshee.Plugins;
+using Banshee.Database;
 
 using Mono.Unix;
 
-using Sql;
-
 namespace Banshee.SmartPlaylist
 {
     public class SmartPlaylistSource : Banshee.Sources.ChildSource
@@ -107,15 +106,18 @@ namespace Banshee.SmartPlaylist
             LimitNumber = limit_number;
             LimitCriterion = limit_criterion;
 
-            Statement query = new Insert("SmartPlaylists", true,
-                "Name", Name,
-                "Condition", Condition,
-                "OrderBy", OrderBy,
-                "LimitNumber", LimitNumber,
-                "LimitCriterion", LimitCriterion
+            DbCommand command = new DbCommand(@"
+                INSERT INTO SmartPlaylists
+                    (Name, Condition, OrderBy, LimitNumber, LimitCriterion)
+                    VALUES (:name, :condition, :orderby, :limitnumber, :limitcriterion)",
+                    "name", Name, 
+                    "condition", Condition, 
+                    "orderby", OrderBy, 
+                    "limitnumber", LimitNumber, 
+                    "limitcriterion", LimitCriterion
             );
 
-            Id = Globals.Library.Db.Execute(query);
+            Id = Globals.Library.Db.Execute(command);
 
             Globals.Library.TrackRemoved += OnLibraryTrackRemoved;
 
@@ -157,8 +159,9 @@ namespace Banshee.SmartPlaylist
             //Console.WriteLine ("Refreshing smart playlist {0} with condition {1}", Source.Name, Condition);
 
             // Delete existing tracks
-            Globals.Library.Db.Execute(String.Format(
-                "DELETE FROM SmartPlaylistEntries WHERE PlaylistID = {0}", Id
+            Globals.Library.Db.Execute(new DbCommand(
+                "DELETE FROM SmartPlaylistEntries WHERE PlaylistID = :playlist_id",
+                "playlist_id", Id
             ));
 
             foreach (TrackInfo track in tracks)
@@ -174,11 +177,11 @@ namespace Banshee.SmartPlaylist
             ));
 
             // Load the new tracks in
-            IDataReader reader = Globals.Library.Db.Query(String.Format(
+            IDataReader reader = Globals.Library.Db.Query(new DbCommand(
                 @"SELECT TrackID 
                     FROM SmartPlaylistEntries
-                    WHERE PlaylistID = '{0}'",
-                    Id
+                    WHERE PlaylistID = :playlist_id",
+                    "playlist_id", Id
             ));
             
             // If the limit is by any but songs, we need to prune the list up based on the desired 
@@ -312,15 +315,24 @@ namespace Banshee.SmartPlaylist
         {
             Timer t = new Timer ("Commit");
 
-            Statement query = new Update("SmartPlaylists",
-                "Name", Name,
-                "Condition", Condition,
-                "OrderBy", OrderBy,
-                "LimitNumber", LimitNumber,
-                "LimitCriterion", LimitCriterion) + 
-                new Where(new Compare("PlaylistID", Op.EqualTo, Id));
+            DbCommand command = new DbCommand(@"
+                UPDATE SmartPlaylists
+                SET 
+                    Name = :name,
+                    Condition = :condition,
+                    OrderBy = :orderby,
+                    LimitNumber = :limitnumber,
+                    LimitCriterion = :limitcriterion
+                WHERE PlaylistID = :playlistid",
+                "name", Name,
+                "condition", Condition,
+                "orderby", OrderBy,
+                "limitnumber", LimitNumber,
+                "limitcriterion", LimitCriterion,
+                "playlistid", Id
+            );
 
-            Globals.Library.Db.Execute(query);
+            Globals.Library.Db.Execute(command);
 
             // Make sure the tracks are up to date
             Globals.Library.Db.Execute(String.Format(
