@@ -1,9 +1,8 @@
-
 /***************************************************************************
  *  DBusRemote.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover (aaron@abock.org)
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -28,20 +27,22 @@
  */
  
 using System;
-using DBus;
+using NDesk.DBus;
+using org.freedesktop.DBus;
 
 namespace Banshee.Base
 {
     public class DBusRemote
     {
-        private Service service;
-        private Connection connection;
-        
+        public const string BusName = "org.gnome.Banshee";
+        public const string ObjectRoot = "/org/gnome/Banshee";
+
         public DBusRemote()
         {
             try {
-                connection = Bus.GetSessionBus();
-                service = new Service(connection, "org.gnome.Banshee");
+                NameReply nameReply = Bus.Session.RequestName(BusName);
+                // TODO: error handling based on nameReply. should probably throw if 
+                // nameReply is anything other than NameReply.PrimaryOwner
             } catch(Exception e) {
                 LogCore.Instance.PushWarning("Could not connect to D-Bus", 
                     "D-Bus support will be disabled for this instance: " + e.Message, false);
@@ -50,16 +51,14 @@ namespace Banshee.Base
        
         public void RegisterObject(object o, string objectName)
         {
-            if(service != null) {
-                service.RegisterObject(o, "/org/gnome/Banshee/" + objectName);
+            if(Bus.Session != null) {
+                Bus.Session.Register(BusName, new ObjectPath(ObjectRoot + "/" + objectName), o);
             }
         }
        
         public void UnregisterObject(object o)
         {
-            if(service != null) {
-                service.UnregisterObject(o);
-            }
+            //TODO: unregistering objects with managed dbus
         }
     }
 }
