@@ -1,9 +1,8 @@
-
 /***************************************************************************
  *  TrackInfo.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover <aaron@abock.org>
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -49,7 +48,7 @@ namespace Banshee.Base
     
     public abstract class TrackInfo
     {
-        protected Uri uri;
+        protected SafeUri uri;
         protected string mimetype;
         protected string artist;
         protected string album;
@@ -86,6 +85,8 @@ namespace Banshee.Base
         private int uid;
         
         private static int next_id = 1;
+
+        public event EventHandler Changed;
         
         protected TrackInfo()
         {
@@ -108,6 +109,14 @@ namespace Banshee.Base
         {
         }
 
+        protected virtual void OnChanged()
+        {
+            EventHandler handler = Changed;
+            if(handler != null) {
+                handler(this, new EventArgs());
+            }
+        }
+
         public int TrackId { 
             get { 
                 return track_id;
@@ -124,7 +133,7 @@ namespace Banshee.Base
             }
         }
 
-        public Uri Uri { 
+        public SafeUri Uri { 
             get { 
                 return uri;
             }
@@ -154,7 +163,7 @@ namespace Banshee.Base
             }
         }
         
-        private string cover_art_file = null;
+        protected string cover_art_file = null;
         public string CoverArtFileName { 
             get {
                 if(cover_art_file != null) {
@@ -167,7 +176,7 @@ namespace Banshee.Base
                     return path;
                 }
                
-                string basepath = Path.GetDirectoryName(Uri.LocalPath) + Path.DirectorySeparatorChar;
+                string basepath = Path.GetDirectoryName(Uri.AbsolutePath) + Path.DirectorySeparatorChar;
                
                 path = basepath + Asin + ".01._SCLZZZZZZZ_.jpg";
                 if(File.Exists(path)) { 
@@ -198,7 +207,7 @@ namespace Banshee.Base
                 return mimetype;
             } 
             
-            protected set {
+            set {
                 mimetype = value;
             }
         }
