@@ -29,11 +29,14 @@
 using System;
 using System.Threading;
 using System.Runtime.InteropServices;
+using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 using System.Reflection;
 using System.Text;
 using System.Text.RegularExpressions; 
 using System.Diagnostics;
+using System.Globalization;
 using Mono.Unix;
  
 namespace Banshee.Base
@@ -330,73 +333,29 @@ namespace Banshee.Base
         {
             return Convert.ToString(str[0]).ToUpper() + str.Substring(1);
         }
+        
+        /// <summary>
+        /// Works the same as String.IndexOf() except it ignores the differences
+        /// in case and nonspacing combining characters (such as diacritics).
+        /// </summary>
+        /// <remarks>
+        /// It also ignores the differences between Japanese hiragana and
+        /// katakana characters and the differences in character width (for
+        /// example, Japanese katakana characters can be written as full-width
+        /// or half-width). But I don't know Japanese so this might be an
+        /// overkill.
+        /// </remarks>
+        public static int RelaxedIndexOf(string haystack, string needle)
+        {
+            return CultureInfo.CurrentCulture.CompareInfo.IndexOf(haystack, needle,
+                CompareOptions.IgnoreCase | CompareOptions.IgnoreNonSpace |
+                CompareOptions.IgnoreKanaType | CompareOptions.IgnoreWidth);
+        }
     }
     
     public static class PathUtil
     {
-        private static char[] CharsToQuote = { ';', '?', ':', '@', '&', '=', '$', ',', '#', '%' };
-       
-        [DllImport("libglib-2.0.so")]
-        private static extern IntPtr g_filename_to_uri(IntPtr filename, IntPtr hostname, IntPtr error);
-       
-        public static string FilenameToUri(string localPath)
-        {
-            // TODO: replace with managed conversion to avoid marshalling
-            IntPtr path_ptr = GLib.Marshaller.StringToPtrGStrdup(localPath);
-            IntPtr uri_ptr = g_filename_to_uri(path_ptr, IntPtr.Zero, IntPtr.Zero);
-            GLib.Marshaller.Free(path_ptr);
-
-            if(uri_ptr == IntPtr.Zero) {
-                throw new ApplicationException("Filename path must be absolute");
-            }
-
-            string uri = GLib.Marshaller.Utf8PtrToString(uri_ptr);
-            GLib.Marshaller.Free(uri_ptr);
-            
-            return uri;
-        }
-       
-        public static Uri PathToFileUri(string path)
-        {
-            path = Path.GetFullPath(path);
-            
-            try {
-                return new Uri(FilenameToUri(path));
-            } catch {
-                Console.WriteLine("Could not use g_filename_to_uri for {0}, " +
-                    "falling back on CharsToQuote.", path);
-            }
-            
-            StringBuilder builder = new StringBuilder();
-            builder.Append(Uri.UriSchemeFile);
-            builder.Append(Uri.SchemeDelimiter);
-            
-            int i;
-            while((i = path.IndexOfAny(CharsToQuote)) != -1) {
-                if(i > 0) {
-                    builder.Append(path.Substring(0, i));
-                }
-                
-                builder.Append(Uri.HexEscape(path[i]));
-                path = path.Substring(i + 1);
-            }
-            
-            builder.Append(path);
-            
-            return new Uri(builder.ToString(), true);
-        }
-        
-        public static string FileUriStringToPath(string uri)
-        {
-            return FileUriToPath(new Uri(uri));
-        }
-        
-        public static string FileUriToPath(Uri uri)
-        {
-            return uri.LocalPath;
-        }
-        
-        public static string MakeFileNameKey(Uri uri)
+        public static string MakeFileNameKey(SafeUri uri)
         {
             string path = uri.LocalPath;
             return Path.GetDirectoryName(path) + 
@@ -429,4 +388,92 @@ namespace Banshee.Base
             return reader.ReadToEnd();    
         }
     }
+    
+    public static class NamingUtil
+    {
+        public delegate bool PostfixDuplicateIncrementHandler(string check);
+    
+        public static string GenerateTrackCollectionName(IEnumerable tracks, string fallback)
+        {
+            Dictionary<string, int> weight_map = new Dictionary<string, int>();
+            
+            if(tracks == null) {
+                return fallback;
+            }
+            
+            foreach(TrackInfo track in tracks) {
+                string artist = null;
+                string album = null;
+                
+                if(track.Artist != null) {
+                    artist = track.Artist.Trim();
+                    if(artist == String.Empty) {
+                        artist = null;
+                    }
+                }
+                
+                if(track.Album != null) {
+                    album = track.Album.Trim();
+                    if(album == String.Empty) {
+                        album = null;
+                    }
+                }
+                
+                if(artist != null && album != null) {
+                    IncrementCandidate(weight_map, "\0" + artist + " - " + album);
+                    IncrementCandidate(weight_map, artist);
+                    IncrementCandidate(weight_map, album);
+                } else if(artist != null) {
+                    IncrementCandidate(weight_map, artist);
+                } else if(album != null) {
+                    IncrementCandidate(weight_map, album);
+                }
+            }
+            
+            int max_hit_count = 0;
+            string max_candidate = fallback;
+            
+            List<string> sorted_keys = new List<string>(weight_map.Keys);
+            sorted_keys.Sort();
+            
+            foreach(string candidate in sorted_keys) {
+                int current_hit_count = weight_map[candidate];
+                if(current_hit_count > max_hit_count) {
+                    max_hit_count = current_hit_count;
+                    max_candidate = candidate;
+                }
+            }
+            
+            if(max_candidate[0] == '\0') {
+                return max_candidate.Substring(1);
+            }
+            
+            return max_candidate;
+        }
+        
+        private static void IncrementCandidate(Dictionary<string, int> map, string hit)
+        {
+            if(map.ContainsKey(hit)) {
+                map[hit]++;
+            } else {
+                map.Add(hit, 1);
+            }
+        }
+        
+        public static string PostfixDuplicate(string prefix, PostfixDuplicateIncrementHandler duplicateHandler)
+        {
+            if(duplicateHandler == null) {
+                throw new ArgumentNullException("A PostfixDuplicateIncrementHandler delegate must be given");
+            }
+            
+            string name = prefix;
+            for(int i = 1; true; i++) {
+                if(!duplicateHandler(name)) {
+                    return name;
+                }
+                
+                name = prefix + " " + i;
+            }
+        }
+    }
 }
