@@ -37,7 +37,6 @@ using Banshee.Gstreamer;
 
 namespace Banshee.MediaEngine.Gstreamer
 {
-#if GSTREAMER_0_10
     internal delegate void GstPlaybackEosCallback(IntPtr engine);
     internal delegate void GstPlaybackErrorCallback(IntPtr engine, IntPtr error, IntPtr debug);
     internal delegate void GstPlaybackStateChangedCallback(IntPtr engine, int old_state, int new_state, int pending_state);
@@ -94,7 +93,7 @@ namespace Banshee.MediaEngine.Gstreamer
             base.Close();
         }
         
-        protected override void OpenUri(Uri uri)
+        protected override void OpenUri(SafeUri uri)
         {
             IntPtr uri_ptr = GLib.Marshaller.StringToPtrGStrdup(uri.AbsoluteUri);
             gst_playback_open(handle, uri_ptr);
@@ -271,176 +270,4 @@ namespace Banshee.MediaEngine.Gstreamer
         private static extern bool gst_playback_get_pipeline_elements(HandleRef engine, out IntPtr playbin,
             out IntPtr audiobin, out IntPtr audiotee);    
     }
-    
-    
-#else
-
-
-    internal delegate void GpeErrorCallback(IntPtr engine, IntPtr error);
-    internal delegate void GpeIterateCallback(IntPtr engine, int position, int length);
-    internal delegate void GpeEndOfStreamCallback(IntPtr engine);
-
-    public class GstreamerPlayerEngine : PlayerEngine
-    {
-        private HandleRef handle;
-
-        private GpeErrorCallback error_cb;
-        private GpeIterateCallback iterate_cb;
-        private GpeEndOfStreamCallback eos_cb;
-
-        public GstreamerPlayerEngine()
-        {
-            IntPtr ptr = gpe_new();
-            
-            if(ptr == IntPtr.Zero) {
-                throw new ApplicationException(Catalog.GetString("Could not initialize GStreamer library"));
-            }
-            
-            handle = new HandleRef(this, ptr);
-            
-            error_cb = new GpeErrorCallback(OnError);
-            iterate_cb = new GpeIterateCallback(OnIterate);
-            eos_cb = new GpeEndOfStreamCallback(OnEndOfStream);
-            
-            gpe_set_end_of_stream_handler(handle, eos_cb);
-            gpe_set_error_handler(handle, error_cb);
-            gpe_set_iterate_handler(handle, iterate_cb);
-        }
-        
-        public override void Dispose()
-        {
-            base.Dispose();
-            gpe_free(handle);
-        }
-            
-        protected override void OpenUri(Uri uri)
-        {
-            gpe_open(handle, uri.AbsoluteUri);
-        }
-        
-        public override void Close()
-        {
-            gpe_stop(handle);
-            base.Close();
-        }
-            
-        public override void Play()
-        {
-            gpe_play(handle);
-            OnStateChanged(PlayerEngineState.Playing);
-        }
-        
-        public override void Pause()
-        {
-            gpe_pause(handle);
-            OnStateChanged(PlayerEngineState.Paused);
-        }
-        
-        private void OnEndOfStream(IntPtr engine)
-        {
-            OnEventChanged(PlayerEngineEvent.EndOfStream);
-        }
-        
-        private void OnError(IntPtr engine, IntPtr messagePtr)
-        {
-            OnEventChanged(PlayerEngineEvent.Error, Marshal.PtrToStringAnsi(messagePtr));
-        }
-        
-        private void OnIterate(IntPtr engine, int position, int total)
-        {
-            OnEventChanged(PlayerEngineEvent.Iterate);
-        }
-           
-        public override ushort Volume {
-            get { return (ushort)gpe_get_volume(handle); }
-            set { 
-                gpe_set_volume(handle, (int)value);
-                OnEventChanged(PlayerEngineEvent.Volume);
-            }
-        }
-           
-        public override uint Position { 
-            get { return (uint)gpe_get_position(handle); }
-            set { 
-                gpe_set_position(handle, (int)value);
-                OnEventChanged(PlayerEngineEvent.Seek);
-            }
-        }
-           
-        public override uint Length {
-            get { return (uint)gpe_get_length(handle); }
-        }
-        
-        public override string Id {
-            get { return "gstreamer"; }
-        }
-        
-        public override string Name {
-            get { return "GStreamer 0.8"; }
-        }
-        
-        private static string [] source_capabilities = { "file", "http", "cdda" };
-        public override IEnumerable SourceCapabilities {
-            get { return source_capabilities; }
-        }
-                
-        private static string [] decoder_capabilities = { "ogg", "wma", "asf", "flac" };
-        public override IEnumerable ExplicitDecoderCapabilities {
-            get { return decoder_capabilities; }
-        }
-        
-        [DllImport("libbanshee")]
-        private static extern IntPtr gpe_new();
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_free(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_set_end_of_stream_handler(HandleRef handle, GpeEndOfStreamCallback cb);
-            
-        [DllImport("libbanshee")]
-        private static extern void gpe_set_error_handler(HandleRef handle, GpeErrorCallback cb);
-            
-        [DllImport("libbanshee")]
-        private static extern void gpe_set_iterate_handler(HandleRef handle, GpeIterateCallback cb);
-
-        [DllImport("libbanshee")]
-        private static extern bool gpe_open(HandleRef handle, string file);
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_play(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_pause(HandleRef handle);
-    
-        [DllImport("libbanshee")]
-        private static extern void gpe_stop(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_set_volume(HandleRef handle,
-            int volume);
-        
-        [DllImport("libbanshee")]
-        private static extern int gpe_get_volume(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern void gpe_set_position(HandleRef handle,
-            int position);
-            
-        [DllImport("libbanshee")]
-        private static extern int gpe_get_position(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern int gpe_get_length(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern bool gpe_is_eos(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern IntPtr gpe_get_error(HandleRef handle);
-        
-        [DllImport("libbanshee")]
-        private static extern bool gpe_have_error(HandleRef handle);
-    }
-#endif
 }
