@@ -29,11 +29,14 @@
  
 using System;
 using System.Collections;
+using System.Collections.Generic;
 using DAAP;
 
+using Banshee.Base;
+
 namespace Banshee.Plugins.Daap
 {
-    internal class DatabaseProxy : IEnumerable
+    internal class DatabaseProxy : IEnumerable<TrackInfo>, IEnumerable
     {
         private DAAP.Database database;
         
@@ -41,7 +44,12 @@ namespace Banshee.Plugins.Daap
         {
         }
         
-        public IEnumerator GetEnumerator()
+        IEnumerator IEnumerable.GetEnumerator()
+        {
+            return GetEnumerator();
+        }
+        
+        public IEnumerator<TrackInfo> GetEnumerator()
         {
             return new DatabaseProxyEnumerator(database);
         }
@@ -56,7 +64,7 @@ namespace Banshee.Plugins.Daap
             }
         }
         
-        private class DatabaseProxyEnumerator : IEnumerator
+        private class DatabaseProxyEnumerator : IEnumerator<TrackInfo>, IEnumerator, IDisposable
         {
             private DAAP.Database database;
             private int index = -1;
@@ -65,10 +73,14 @@ namespace Banshee.Plugins.Daap
             {
                 this.database = database;
             }
+            
+            public void Dispose()
+            {
+            }
 
             public bool MoveNext()
             {
-                if(database != null && ++index < database.SongCount) {
+                if(database != null && ++index < database.TrackCount) {
                     return true;
                 }
                 
@@ -81,12 +93,16 @@ namespace Banshee.Plugins.Daap
                 index = -1;
             }
             
-            public object Current {
+            object IEnumerator.Current {
+                get { return Current; }
+            }
+            
+            public TrackInfo Current {
                 get {
                     if(database != null) {
-                        DAAP.Song song = database.SongAt(index);
-                        if(song != null) {
-                            return new DaapTrackInfo(song, database);
+                        DAAP.Track track = database.TrackAt(index);
+                        if(track != null) {
+                            return new DaapTrackInfo(track, database);
                         }
                     }
                     
