@@ -44,40 +44,11 @@ namespace Banshee.Widgets
             QueueDraw();
         }
 
-        public static Gdk.Color ColorBlend(Gdk.Color a, Gdk.Color b, double blend)
-        {
-            if(blend < 0.0 || blend > 1.0) {
-                throw new ApplicationException("blend < 0.0 || blend > 1.0");
-            }
-            
-            double blendRatio = 1.0 - blend;
-
-            int aR = a.Red >> 8;
-            int aG = a.Green >> 8;
-            int aB = a.Blue >> 8;
-
-            int bR = b.Red >> 8;
-            int bG = b.Green >> 8;
-            int bB = b.Blue >> 8;
-
-            double mR = aR + bR;
-            double mG = aG + bG;
-            double mB = aB + bB;
-
-            double blR = mR * blendRatio;
-            double blG = mG * blendRatio;
-            double blB = mB * blendRatio;
-
-            Gdk.Color color = new Gdk.Color((byte)blR, (byte)blG, (byte)blB);
-            Gdk.Colormap.System.AllocColor(ref color, true, true);
-            return color;
-        }
-
         protected override bool OnExposeEvent(Gdk.EventExpose evnt)
         {
             if(bar_gc == null) {
                 bar_gc = new Gdk.GC(GdkWindow);
-                Gdk.Color color = ColorBlend(Style.Background(StateType.Normal), 
+                Gdk.Color color = DrawingUtilities.ColorBlend(Style.Background(StateType.Normal), 
                     Style.Foreground(StateType.Normal), 0.2);
                 bar_gc.Background = color;
                 bar_gc.Foreground = color;
