@@ -28,7 +28,7 @@
 
 using System;
 using System.IO;
-//using System.Data;
+
 using System.Threading;
 using System.Reflection;
 using System.Collections;
@@ -40,8 +40,6 @@ using Gtk;
 using Gdk;
 using Glade;
 
-using Sql;
-
 using Banshee.Widgets;
 using Banshee.Base;
 using Banshee.MediaEngine;
@@ -685,7 +683,8 @@ namespace Banshee
         {
             bool handled = false;
             
-            if(WindowPlayer.Focus is Entry && Gtk.Global.CurrentEvent is Gdk.EventKey) {
+            if(WindowPlayer.Focus is Entry && Gtk.Global.CurrentEvent is Gdk.EventKey &&
+                (Gtk.Global.CurrentEvent as Gdk.EventKey).State == Gdk.ModifierType.None) {
                 if(accel_group_active) {
                     WindowPlayer.RemoveAccelGroup(Globals.ActionManager.UI.AccelGroup);
                     accel_group_active = false;
@@ -1249,9 +1248,9 @@ namespace Banshee
             dialog.Title = args.Entry.ShortMessage;
             IconThemeUtils.SetWindowIcon(dialog);
             
-            dialog.Response += delegate(object o, ResponseArgs args)
+            dialog.Response += delegate(object obj, ResponseArgs response_args)
             {
-                (o as Dialog).Destroy();
+                (obj as Dialog).Destroy();
             };
             
             dialog.ShowAll();
@@ -2123,7 +2122,7 @@ namespace Banshee
         {
             Banshee.Gui.Dialogs.TrackEditor propEdit = 
                 new Banshee.Gui.Dialogs.TrackEditor(playlistView.SelectedTrackInfoMultiple);
-            propEdit.Saved += delegate(object o, EventArgs args) {
+            propEdit.Saved += delegate {
                 playlistView.QueueDraw();
             };
         }
@@ -2251,11 +2250,11 @@ namespace Banshee
             if(log_viewer == null) {
                 log_viewer = new Banshee.Gui.Dialogs.LogCoreDialog(LogCore.Instance, WindowPlayer);
                 
-                log_viewer.Response += delegate(object o, ResponseArgs args) {
+                log_viewer.Response += delegate {
                     log_viewer.Hide();
                 };
                 
-                log_viewer.DeleteEvent += delegate(object o, DeleteEventArgs args) {
+                log_viewer.DeleteEvent += delegate {
                     log_viewer.Destroy();
                     log_viewer = null;
                 };
